@@ -2,7 +2,7 @@
 import os
 from ._version import get_versions
 from .LocalClassifierPerNode import LocalClassifierPerNode
-from .LocalClassifierPerParent import LocalClassifierPerParent
+from .LocalClassifierPerParentNode import LocalClassifierPerParentNode
 from .LocalClassifierPerLevel import LocalClassifierPerLevel
 
 __version__ = get_versions()["version"]
@@ -10,6 +10,6 @@ del get_versions
 
 __all__ = [
     "LocalClassifierPerNode",
-    "LocalClassifierPerParent",
+    "LocalClassifierPerParentNode",
     "LocalClassifierPerLevel",
 ]
